==> jbpm-quarkus-example-0.2.0-sources.jar: org/acme/kogito/RulesE405F32A817FD57B535435BB6FB960B3.java <==
package org.acme.kogito;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.kie.kogito.examples.demo.Person;
import org.drools.model.Model;

public class RulesE405F32A817FD57B535435BB6FB960B3 implements Model {

    public final static DateTimeFormatter DATE_TIME_FORMATTER = DateTimeFormatter.ofPattern(DateUtils.getDateFormatMask());

    @Override
    public String getName() {
        return "org.acme.kogito";
    }

    public static Date string_2_date(String s) {
        return GregorianCalendar.from(LocalDate.parse(s,
                                                      DATE_TIME_FORMATTER).atStartOfDay(ZoneId.systemDefault()))
                                .getTime();
    }

    /**
     * With the following expression ID:
     * org.drools.modelcompiler.builder.generator.DRLIdGenerator@7d8f7059
     */
    @Override
    public List<org.drools.model.Rule> getRules() {
        return rules;
    }

    @Override
    public List<org.drools.model.EntryPoint> getEntryPoints() {
        return Collections.emptyList();
    }

    @Override
    public List<org.drools.model.Global> getGlobals() {
        return globals;
    }

    @Override
    public List<org.drools.model.Query> getQueries() {
        return queries;
    }

    @Override
    public List<org.drools.model.TypeMetaData> getTypeMetaDatas() {
        return typeMetaDatas;
    }

    List<org.drools.model.Query> queries = Collections.emptyList();

    List<org.drools.model.Global> globals = Collections.emptyList();

    List<org.drools.model.TypeMetaData> typeMetaDatas = Collections.emptyList();

    public static List<Rule> rulesList = Arrays.asList(RulesE405F32A817FD57B535435BB6FB960B3_rule_Is_32adult.rule_Is_32adult());

    List<org.drools.model.Rule> rules = rulesList;
}

==> jbpm-quarkus-example-0.3.0-sources.jar: org/acme/kogito/RulesE405F32A817FD57B535435BB6FB960B3.java <==
package org.acme.kogito;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.kie.kogito.examples.demo.Person;
import org.drools.model.Model;

public class RulesE405F32A817FD57B535435BB6FB960B3 implements Model {

    public final static DateTimeFormatter DATE_TIME_FORMATTER = DateTimeFormatter.ofPattern(DateUtils.getDateFormatMask(),
                                                                                            Locale.ENGLISH);

    @Override
    public String getName() {
        return "org.acme.kogito";
    }

    public static Date string_2_date(String s) {
        return GregorianCalendar.from(LocalDate.parse(s,
                                                      DATE_TIME_FORMATTER).atStartOfDay(ZoneId.systemDefault()))
                                .getTime();
    }

    @Override
    public List<org.drools.model.EntryPoint> getEntryPoints() {
        return Collections.emptyList();
    }

    @Override
    public List<org.drools.model.Global> getGlobals() {
        return globals;
    }

    @Override
    public List<org.drools.model.TypeMetaData> getTypeMetaDatas() {
        return typeMetaDatas;
    }

    List<org.drools.model.Global> globals = Collections.emptyList();

    List<org.drools.model.TypeMetaData> typeMetaDatas = Collections.emptyList();

    /**
     * With the following expression ID:
     * org.drools.modelcompiler.builder.generator.DRLIdGenerator@40e64c28
     */
    @Override
    public List<org.drools.model.Rule> getRules() {
        return rules;
    }

    public static List<Rule> rulesList = Arrays.asList(RulesE405F32A817FD57B535435BB6FB960B3RuleMethods0.rule_Is_32adult());

    List<org.drools.model.Rule> rules = rulesList;

    @Override
    public List<org.drools.model.Query> getQueries() {
        return java.util.Collections.emptyList();
    }
}
